@@ -10,7 +10,7 @@ use Lemonldap::NG::Handler::CGI qw(:globalStorage :locationRules);    #inherits
 use Lemonldap::NG::Common::Conf;              #link protected conf Configuration
 use Lemonldap::NG::Common::Conf::Constants;   #inherits
 
-our $VERSION = '1.4.0';
+our $VERSION = '1.4.1';
 our @ISA     = qw(
   Lemonldap::NG::Handler::CGI
   Lemonldap::NG::Manager::Downloader
@@ -34,6 +34,11 @@ sub new {
     my $conf = Lemonldap::NG::Common::Conf->new( $args->{configStorage} )
       or Lemonldap::NG::Handler::CGI->abort( 'Unable to get configuration',
         $Lemonldap::NG::Common::Conf::msg );
+
+    if ( my $globalconf = $conf->getConf() ) {
+        $args->{$_} ||= $globalconf->{$_} foreach (qw/portal/);
+    }
+
     if ( my $localconf = $conf->getLocalConf(MANAGERSECTION) ) {
         $args->{$_} ||= $localconf->{$_} foreach ( keys %$localconf );
     }
