@@ -476,13 +476,16 @@ sub en {
         samlSPMetaDataOptionsEnableIDPInitiatedURL =>
           'Enable use of IDP initiated URL',
         samlSPMetaDataOptionsNameIDSessionKey => 'Force NameID session key',
-        samlServiceMetaData                   => 'SAML 2 Service',
-        samlEntityID                          => 'Entity Identifier',
-        samlOrganization                      => 'Organization',
-        samlOrganizationDisplayName           => 'Display Name',
-        samlOrganizationName                  => 'Name',
-        samlOrganizationURL                   => 'URL',
-        samlSPSSODescriptor                   => 'Service Provider',
+        samlSPMetaDataOptionsSessionNotOnOrAfterTimeout =>
+          'sessionNotOnOrAfter duration',
+        samlSPMetaDataOptionsNotOnOrAfterTimeout => 'notOnOrAfter duration',
+        samlServiceMetaData                      => 'SAML 2 Service',
+        samlEntityID                             => 'Entity Identifier',
+        samlOrganization                         => 'Organization',
+        samlOrganizationDisplayName              => 'Display Name',
+        samlOrganizationName                     => 'Name',
+        samlOrganizationURL                      => 'URL',
+        samlSPSSODescriptor                      => 'Service Provider',
         samlSPSSODescriptorAuthnRequestsSigned =>
           'Signed Authentication Request',
         samlSPSSODescriptorWantAssertionsSigned => 'Want Assertions Signed',
@@ -988,13 +991,16 @@ sub fr {
           "Autoriser l'utilisation d'URL SSO initié par l'IDP",
         samlSPMetaDataOptionsNameIDSessionKey =>
           "Forcer la clé de session NameID",
-        samlServiceMetaData         => 'Service SAML 2',
-        samlEntityID                => 'Identifiant d\'entité',
-        samlOrganization            => 'Organisation',
-        samlOrganizationDisplayName => 'Nom affiché',
-        samlOrganizationName        => 'Nom',
-        samlOrganizationURL         => 'URL',
-        samlSPSSODescriptor         => 'Fournisseur de service',
+        samlSPMetaDataOptionsSessionNotOnOrAfterTimeout =>
+          'Durée sessionNotOnOrAfter',
+        samlSPMetaDataOptionsNotOnOrAfterTimeout => 'Durée notOnOrAfter',
+        samlServiceMetaData                      => 'Service SAML 2',
+        samlEntityID                             => 'Identifiant d\'entité',
+        samlOrganization                         => 'Organisation',
+        samlOrganizationDisplayName              => 'Nom affiché',
+        samlOrganizationName                     => 'Nom',
+        samlOrganizationURL                      => 'URL',
+        samlSPSSODescriptor                      => 'Fournisseur de service',
         samlSPSSODescriptorAuthnRequestsSigned =>
           'Requêtes d\'authentification signées',
         samlSPSSODescriptorWantAssertionsSigned =>
